@@ -8,7 +8,7 @@ from cmor.cmor_const import *
 
 from cmor.pywrapper import (
     CMORError, axis, variable, write, setup, load_table, set_table, zfactor,
-    close, grid, set_grid_mapping, set_crs, time_varying_grid_coordinate,
+    close, grid, set_grid_mapping, set_crs,
     dataset_json, set_cur_dataset_attribute, get_cur_dataset_attribute,
     has_cur_dataset_attribute, set_variable_attribute, get_variable_attribute,
     has_variable_attribute, get_final_filename, set_deflate, set_zstandard,
