@@ -18,7 +18,7 @@ import unittest
 import sys
 import os
 import tempfile
-import pkgutil
+import importlib.util
 import netCDF4
 import base_CMIP6_CV
 
@@ -61,7 +61,7 @@ class TestCase(base_CMIP6_CV.BaseCVsTest):
         a = f.__dict__["tracking_id"].split('/')[0]
         self.assertNotIn("hdl:21.14100/", a)
 
-    @unittest.skipIf(pkgutil.find_loader("cdms2") is None, "cdms2 not installed")
+    @unittest.skipIf(importlib.util.find_spec("cdms2") is None, "cdms2 not installed")
     def testCMIP6_CDMS2(self):
         import cdms2
 
