@@ -59,7 +59,7 @@ class TestCase(unittest.TestCase):
         try:
 
             cmor.setup(inpath='Tables', netcdf_file_action=cmor.CMOR_REPLACE)
-            cmor.dataset_json("Test/common_user_input.json")
+            cmor.dataset_json("Test/CMOR_input_example.json")
             cmor.set_cur_dataset_attribute("experiment_id", "piControlbad")
 
             cmor.load_table("CMIP6_Omon.json")
