@@ -7,7 +7,7 @@ cmor.setup(inpath=ipth,
            netcdf_file_action=cmor.CMOR_REPLACE,
            logfile=None)
 
-cmor.dataset_json("Test/common_user_input.json")
+cmor.dataset_json("Test/CMOR_input_example.json")
 
 cmor.load_table("CMIP6_Amon.json")
 
